********************************************************************************
*This file is used to generate Figure 2.




global date 		= "15Jun22"
global workdir 		= "B:\CBDC-Li"
global data 		= "$workdir\data"


clear all
set maxvar 120000

cap mkdir "$workdir\\results\\$date"
cap mkdir "$workdir\\results\\$date\\CBDC prediction with bank responses"
cap mkdir "$workdir\\results\\$date\\CBDC prediction with bank responses\\Different N and mean_pretax_rate"

global results 		= "$workdir\\results\\$date\\CBDC prediction with bank responses\\Different N and mean_pretax_rate"



********************************************************************************
*FIGURE 2 - AGGREGATE CBDC SHARES AND NEW EQUILIBIRUM DEPOSIT RATES 
********************************************************************************

//Load data
clear
use  "$workdir/data/counterfactual analysis/$date/no bank responses and mean_pretax_rate/meanshares_dshares_nest_d_cbdc_design_real_real_rho0_gamma0_eta0_year2017.dta", clear


forval yr = 2017(1)2017 {
	cap mkdir  "$results//`yr'"
	
	foreach model in nest_d_cbdc    {
		foreach design in design_real design_d design_c {
			local attr = subinstr("`design'", "design_", "", .)
			foreach rho in 0    {
				foreach gamma in 0 0.2 0.4 0.6 0.8 1 {
					foreach eta in 0 0.2 0.4 0.6 0.8 1 {
						append using "$workdir/data/counterfactual analysis/$date/no bank responses and mean_pretax_rate/meanshares_dshares_`model'_`design'_`attr'_rho`rho'_gamma`gamma'_eta`eta'_year`yr'.dta"
					}
				}				
			}
		}
	}

	duplicates drop	 
  
}

//perfect competition with many banks -> no response in deposit rate
gen nbanks = 10000


forval yr = 2017(1)2017 {
	
	 foreach nbanks in  6  11  20 {
	
		foreach model in nest_d_cbdc    {
			foreach design in design_real design_d design_c {
				local attr = subinstr("`design'", "design_", "", .)
				foreach rho in 0    {
					foreach gamma in 0 0.2 0.4 0.6 0.8 1 {
						foreach eta in 0 0.2 0.4 0.6 0.8 1 {
							append using "$workdir/data/counterfactual analysis/$date/bank responses N`nbanks' mean_pretax_rate/meanshares_dshares_`model'_`design'_`attr'_rho`rho'_gamma`gamma'_eta`eta'_year`yr'.dta"
						}
					}				
				}
			}
		}
	
		duplicates drop	 
        replace nbanks = `nbanks' if nbanks == . 
	}

}


*-------------------------------------------------------------------------------
//plot figures 
//x-axis = CBDC-specific effects; lines = different N

//without banks' responses, the average deposit rate stays at 0.08%
replace rate_new = 0.08 if nbanks == 10000

//v is the variable on y-axis
foreach v in as_CBDC  rate_new {
	local rho = 0
	local model nest_d_cbdc
	local design  design_real
	local yr = 2017

	graph twoway (scatter `v' gamma if nbanks == 6 &  rho == float(`rho') & eta == float(gamma) & attr_real != . & nest == "`model'", msize(medium) m(circle_hollow))  ///
	(scatter `v' gamma if nbanks == 11 &  rho == float(`rho') & eta == float(gamma) & attr_real != . & nest == "`model'", msize(medium) m(square) mcolor(black))  ///
	(scatter `v' gamma if nbanks == 20 &  rho == float(`rho') & eta == float(gamma) & attr_real != . & nest == "`model'", msize(medlarge) m(X) mcolor(black))   ///
	(scatter `v' gamma if nbanks == 10000 &  rho == float(`rho') & eta == float(gamma) & attr_real != . & nest == "`model'", msize(medium) m(triangle) mcolor(green)),  ///
	xtitle(CBDC-specific effects, size(medium)) legend( label(1 "N = 6") label(2 "N = 11")  label(3 "N = 20") label(4 "N = {&infinity}") cols(4) pos(6) ring(3) size(medsmall)) xsize(3) ysize(3.2) xlabel(,labsize(medium)) ylabel(,labsize(medsmall)) ytitle("")
	graph export "$results/`yr'/scatter_`v'_against_eta_gamma_differentN_rho`rho'_`model'_`design'.pdf", as(pdf) replace
	
}


